# gigman

gitignore manager cli, written in Python

- easily add/remove templates from [github/gitignore](https://github.com/github/gitignore).
- does not touch previous data in your `.gitignore`

![usage](images/usage.gif)

## Install

```
pip install gigman
```

## Usage

```
gigman
```

- Type to filter
- Press enter to add/remove a template
- Ctrl-C to exit
